#######################################
Extending FitBenchmarking Documentation
#######################################

FitBenchmarking is designed to be easily extendable to add new features
to the software.  Below we outline instructions for doing this.

.. toctree::
    :titlesonly:
    :caption: Contents:

    parsers
    jacobian_extend
    controllers
    options_extend
    outputs/index


